/* Tatar Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdtat.html
 */
jQuery.keyboard.layouts['ms-Tatar'] = {
	"name" : "ms-Tatar",
	"lang" : ["tt"],
	"normal" : [
		"\u04BB 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} \u0439 \u04E9 \u0443 \u043A \u0435 \u043D \u0433 \u0448 \u04D9 \u0437 \u0445 \u04AF",
		"\u0444 \u044B \u0432 \u0430 \u043F \u0440 \u043E \u043B \u0434 \u04A3 \u044D \\ {enter}",
		"{shift} \u0491 \u044F \u0447 \u0441 \u043C \u0438 \u0442 \u0497 \u0431 \u044E . {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u04BA ! \" \u2116 ; % : ? * ( ) _ + {bksp}",
		"{tab} \u0419 \u04E8 \u0423 \u041A \u0415 \u041D \u0413 \u0428 \u04D8 \u0417 \u0425 \u04AE",
		"\u0424 \u042B \u0412 \u0410 \u041F \u0420 \u041E \u041B \u0414 \u04A2 \u042D / {enter}",
		"{shift} \u0490 \u042F \u0427 \u0421 \u041C \u0418 \u0422 \u0496 \u0411 \u042E , {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u0451 {empty} @ # $ {empty} {empty} [ ] { } {empty} {empty} {bksp}",
		"{tab} {empty} \u0446 {empty} {empty} {empty} {empty} {empty} {empty} \u0449 {empty} {empty} \u044A",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0436 ' {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u044C < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"\u0401 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} \u0426 {empty} {empty} {empty} {empty} {empty} {empty} \u0429 {empty} {empty} \u042A",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0416 {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u042C {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
