/* Polish (214) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdpl.html
 */
jQuery.keyboard.layouts['ms-Polish (214)'] = {
	"name" : "ms-Polish (214)",
	"lang" : ["pl"],
	"normal" : [
		"\u02DB 1 2 3 4 5 6 7 8 9 0 + ' {bksp}",
		"{tab} q w e r t z u i o p \u017C \u015B",
		"a s d f g h j k l \u0142 \u0105 \u00F3 {enter}",
		"{shift} < y x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00B7 ! \" # \u00A4 % & / ( ) = ? * {bksp}",
		"{tab} Q W E R T Z U I O P \u0144 \u0107",
		"A S D F G H J K L \u0141 \u0119 \u017A {enter}",
		"{shift} > Y X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02C7 ^ \u02D8 \u00B0 \u02DB ` \u00B7 \u00B4 \u02DD \u00A8 \u00B8 {bksp}",
		"{tab} \\ \u00A6 {empty} {empty} {empty} {empty} \u20AC {empty} {empty} {empty} \u00F7 \u00D7",
		"{empty} \u0111 \u0110 {empty} {empty} {empty} {empty} {empty} {empty} $ \u00DF {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} @ { } \u00A7 < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Polish (Programmers) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdpl1.html
 */
jQuery.keyboard.layouts['ms-Polish (Programmers)'] = {
	"name" : "ms-Polish (Programmers)",
	"lang" : ["pl"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ]",
		"a s d f g h j k l ; ' \\ {enter}",
		"{shift} z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { }",
		"A S D F G H J K L : \" | {enter}",
		"{shift} Z X C V B N M < > ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u0119 {empty} {empty} {empty} \u20AC {empty} \u00F3 {empty} {empty} {empty}",
		"\u0105 \u015B {empty} {empty} {empty} {empty} {empty} {empty} \u0142 {empty} {empty} {empty} {enter}",
		"{shift} \u017C \u017A \u0107 {empty} {empty} \u0144 {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u0118 {empty} {empty} {empty} {empty} {empty} \u00D3 {empty} {empty} {empty}",
		"\u0104 \u015A {empty} {empty} {empty} {empty} {empty} {empty} \u0141 {empty} {empty} {empty} {enter}",
		"{shift} \u017B \u0179 \u0106 {empty} {empty} \u0143 {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
