/* Swedish Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdsw.html
 */
jQuery.keyboard.layouts['ms-Swedish'] = {
	"name" : "ms-Swedish",
	"lang" : ["sv"],
	"normal" : [
		"\u00A7 1 2 3 4 5 6 7 8 9 0 + \u00B4 {bksp}",
		"{tab} q w e r t y u i o p \u00E5 \u00A8",
		"a s d f g h j k l \u00F6 \u00E4 ' {enter}",
		"{shift} < z x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00BD ! \" # \u00A4 % & / ( ) = ? ` {bksp}",
		"{tab} Q W E R T Y U I O P \u00C5 ^",
		"A S D F G H J K L \u00D6 \u00C4 * {enter}",
		"{shift} > Z X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} @ \u00A3 $ \u20AC {empty} { [ ] } \\ {empty} {bksp}",
		"{tab} {empty} {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ~",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} | {empty} {empty} {empty} {empty} {empty} {empty} \u00B5 {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Swedish with Sami Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdsw1.html
 */
jQuery.keyboard.layouts['ms-Swedish with Sami'] = {
	"name" : "ms-Swedish with Sami",
	"lang" : ["sv"],
	"normal" : [
		"\u00a7 1 2 3 4 5 6 7 8 9 0 + \u00B4 {bksp}",
		"{tab} q w e r t y u i o p \u00E5 \u00A8",
		"a s d f g h j k l \u00F6 \u00E4 ' {enter}",
		"{shift} < z x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00BD ! \" # \u00A4 % & / ( ) = ? ` {bksp}",
		"{tab} Q W E R T Y U I O P \u00C5 ^",
		"A S D F G H J K L \u00D6 \u00C4 * {enter}",
		"{shift} > Z X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} @ \u00A3 $ \u20AC {empty} { [ ] } \\ {empty} {bksp}",
		"{tab} \u00E2 {empty} \u20AC {empty} \u0167 {empty} {empty} \u00ef \u00f5 {empty} {empty} ~",
		"\u00E1 \u0161 \u0111 \u01e5 \u01E7 \u021F {empty} \u01e9 {empty} \u00F8 \u00E6 {empty} {enter}",
		"{shift} | \u017E {empty} \u010d \u01EF \u0292 \u014B \u00B5 {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} \u00C2 {empty} {empty} {empty} \u0166 {empty} {empty} \u00CF \u00D5 {empty} {empty} {empty}",
		"\u00C1 \u0160 \u0110 \u01E4 \u01E6 \u021e {empty} \u01E8 {empty} \u00D8 \u00C6 {empty} {enter}",
		"{shift} {empty} \u017D {empty} \u010C \u01EE \u01B7 \u014A {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
