/* Inuktitut - Latin Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdiulat.html
 */
jQuery.keyboard.layouts['ms-Inuktitut - Latin'] = {
	"name" : "ms-Inuktitut - Latin",
	"lang" : ["iu"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ 1 2 3 4 5 6 7 8 9 0 _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ! @ # $ % * & \u2022 [ ] {empty} = {bksp}",
		"{tab} \u1590 \u1404 \u1580 \u146e \u144f \u14f0 \u14a6 \u14c3 \u14d6 \u1529 \u201c \u2018 {empty}",
		"\u1592 \u1406 \u1582 \u1470 \u1451 \u14f2 \u14a8 \u14c5 \u14d8 \u2026 \u0142 {enter}",
		"{shift} {empty} \u1594 \u140b \u1584 \u1473 \u1456 \u14f5 \u14ab {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ \u00a2 \u00ae \u00bc \u00bd \u00be ^ \u2154 \u00a9 \u00f7 + {empty} {empty} {bksp}",
		"{tab} \u148c \u1432 \u1547 {empty} \u1672 \u1674 \u1676 \u15a5 \u15a1 {empty} \u201d \u2019 |",
		"\u148e \u1434 \u1549 \u1556 {empty} {empty} \u152b \u1558 \u15a3 {empty} \u0141 {enter}",
		"{shift} | \u1491 \u1439 \u154c { } \u14c8 \u14db {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Inuktitut - Naqittaut Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdinuk2.html
 */
jQuery.keyboard.layouts['ms-Inuktitut - Naqittaut'] = {
	"name" : "ms-Inuktitut - Naqittaut",
	"lang" : ["iu"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { [ |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ! @ # $ % * & \u2022 [ ] {empty} = {bksp}",
		"{tab} \u1590 \u1404 \u1580 \u146e \u144f \u14f0 \u14a6 \u14c3 \u14d6 \u1529 \u201c \u2018 {empty}",
		"\u1592 \u1406 \u1582 \u1470 \u1451 \u14f2 \u14a8 \u14c5 \u14d8 \u014b \u0142 {enter}",
		"{shift} {empty} \u1594 \u140b \u1584 \u1473 \u1456 \u14f5 \u14ab {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ \u00a2 \u00ae \u00bc \u00bd \u00be ^ \u2154 \u00a9 \u00f7 + {empty} {empty} {bksp}",
		"{tab} \u148c \u1432 \u1547 {empty} \u1672 \u1674 \u1676 \u15a5 \u15a1 {empty} \u201d \u2019 |",
		"\u148e \u1434 \u1549 \u1556 {empty} {empty} \u152b \u1558 \u15a3 {empty} \u0141 {enter}",
		"{shift} | \u1491 \u1439 \u154c { } \u14c8 \u14db {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
