/* Malayalam Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdinmal.html
 */
jQuery.keyboard.layouts['ms-Malayalam'] = {
	"name" : "ms-Malayalam",
	"lang" : ["ml"],
	"normal" : [
		"\u0d4a 1 2 3 4 5 6 7 8 9 0 - \u0d43 {bksp}",
		"{tab} \u0d4c \u0d48 \u0d3e \u0d40 \u0d42 \u0d2c \u0d39 \u0d17 \u0d26 \u0d1c \u0d21 {empty}",
		"\u0d4b \u0d47 \u0d4d \u0d3f \u0d41 \u0d2a \u0d30 \u0d15 \u0d24 \u0d1a \u0d1f {enter}",
		"{shift} \u0d46 \u0d02 \u0d2e \u0d28 \u0d35 \u0d32 \u0d38 , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u0d12 {empty} {empty} \u0d4d\u0d30 {empty} {empty} {empty} \u0d15\u0d4d\u0d37 {empty} ( ) \u0d03 \u0d0b {bksp}",
		"{tab} \u0d14 \u0d10 \u0d06 \u0d08 \u0d0a \u0d2d \u0d19 \u0d18 \u0d27 \u0d1d \u0d22 \u0d1e",
		"\u0d13 \u0d0f \u0d05 \u0d07 \u0d09 \u0d2b \u0d31 \u0d16 \u0d25 \u0d1b \u0d20 {enter}",
		"{shift} \u0d0e {empty} \u0d23 {empty} \u0d34 \u0d33 \u0d36 \u0d37 {empty} / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u0d67 \u0d68 \u0d69 \u0d6a \u0d6b \u0d6c \u0d6d \u0d6e \u0d6f \u0d66 {empty} {empty} {bksp}",
		"{tab} \u0d57 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0d60 {bksp}",
		"{tab} {empty} {empty} {empty} \u0d61 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} \u0d0c {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
