/* Maltese 47-Key Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdmlt47.html
 */
jQuery.keyboard.layouts['ms-Maltese 47-Key'] = {
	"name" : "ms-Maltese 47-Key",
	"lang" : ["mt"],
	"normal" : [
		"\u010b 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p \u0121 \u0127 \u017c",
		"a s d f g h j k l ; ' {enter}",
		"{shift} z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u010a ! @ \u20ac $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P \u0120 \u0126 \u017b",
		"A S D F G H J K L : \" {enter}",
		"{shift} Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"` {empty} {empty} \u00a3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00e8 {empty} {empty} {empty} \u00f9 \u00ec \u00f2 {empty} [ ] \\",
		"\u00e0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00c8 {empty} {empty} {empty} \u00d9 \u00cc \u00d2 {empty} { } |",
		"\u00c0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Maltese 48-Key Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdmlt48.html
 */
jQuery.keyboard.layouts['ms-Maltese 48-Key'] = {
	"name" : "ms-Maltese 48-Key",
	"lang" : ["mt"],
	"normal" : [
		"\u010b 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p \u0121 \u0127 #",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \u017c z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u010a ! \" \u20ac $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P \u0120 \u0126 ~",
		"A S D F G H J K L : @ {enter}",
		"{shift} \u017b Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"` {empty} {empty} \u00a3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00e8 {empty} {empty} {empty} \u00f9 \u00ec \u00f2 {empty} [ ] {empty}",
		"\u00e0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} \\ {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"\u00ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00c8 {empty} {empty} {empty} \u00d9 \u00cc \u00d2 {empty} { } {empty}",
		"\u00c0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} | {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
