/* Setswana Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdnso.html
 */
jQuery.keyboard.layouts['ms-Setswana'] = {
	"name" : "ms-Setswana",
	"lang" : ["tn"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00a1 \u00b2 \u00b3 \u00a4 \u20ac \u00bc \u00bd \u00be \u2018 \u2019 \u00a5 \u00d7 {bksp}",
		"{tab} \u00e4 \u00e5 \u00e9 \u00ae \u00fe \u00fc \u00fa \u00ed \u00f3 \u00f6 \u00ab \u00bb \u00ac",
		"\u00e1 \u00df \u00f0 {empty} {empty} {empty} {empty} {empty} \u00f8 \u00b6 \u00b4 {enter}",
		"{shift} {empty} \u00e6 {empty} \u00a9 {empty} {empty} \u00f1 \u00b5 \u00e7 \u0161 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} \u00b9 {empty} {empty} \u00a3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00f7 {bksp}",
		"{tab} \u00c4 \u00c5 \u00c9 {empty} \u00de \u00dc \u00da \u00cd \u00d3 \u00d6 {empty} {empty} \u00a6",
		"\u00c1 \u00a7 \u00d0 {empty} {empty} {empty} {empty} {empty} \u00d8 \u00b0 \u00a8 {enter}",
		"{shift} {empty} \u00c6 {empty} \u00a2 {empty} {empty} \u00d1 {empty} \u00c7 \u0160 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};


/* Setswana Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdnso1.html
 */
jQuery.keyboard.layouts['ms-Setswana (Sesotho sa Leboa)'] = {
	"name" : "ms-Setswana (Sesotho sa Leboa)",
	"lang" : ["tn"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00a1 \u00b2 \u00b3 \u00a4 \u20ac \u00bc \u00bd \u00be \u2018 \u2019 \u00a5 \u00d7 {bksp}",
		"{tab} \u00e4 \u00e5 \u00e9 \u00ae \u00fe \u00fc \u00fa \u00ed \u00f3 \u00f6 \u00ab \u00bb \u00ac",
		"\u00e1 \u00df \u00f0 {empty} {empty} {empty} {empty} {empty} \u00f8 \u00b6 \u00b4 {enter}",
		"{shift} \u00e6 {empty} \u00a9 {empty} {empty} \u00f1 \u00b5 \u00e7 \u0161 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} \u00b9 {empty} {empty} \u00a3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00f7 {bksp}",
		"{tab} \u00c4 \u00c5 \u00c9 {empty} \u00de \u00dc \u00da \u00cd \u00d3 \u00d6 {empty} {empty} \u00a6",
		"\u00c1 \u00a7 \u00d0 {empty} {empty} {empty} {empty} {empty} \u00d8 \u00b0 \u00a8 {enter}",
		"{shift} \u00c6 {empty} \u00a2 {empty} {empty} \u00d1 {empty} \u00c7 \u0160 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
