/* Lithuanian Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdlt1.html
 */
jQuery.keyboard.layouts['ms-Lithuanian'] = {
	"name" : "ms-Lithuanian",
	"lang" : ["lt"],
	"normal" : [
		"` \u0105 \u010d \u0119 \u0117 \u012f \u0161 \u0173 \u016b 9 0 - \u017e {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ \u0104 \u010c \u0118 \u0116 \u012e \u0160 \u0172 \u016a ( ) _ \u017d {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} 1 2 3 4 5 6 7 8 9 0 {empty} = {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} ! @ # $ % ^ & * {empty} {empty} {empty} + {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Lithuanian IBM Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdlt.html
 */
jQuery.keyboard.layouts['ms-Lithuanian IBM'] = {
	"name" : "ms-Lithuanian IBM",
	"lang" : ["lt"],
	"normal" : [
		"` ! \" / ; : , . ? ( ) _ + {bksp}",
		"{tab} \u0105 \u017e e r t y u i o p \u012f \u201c |",
		"a s d f g h j k l \u0173 \u0117 {enter}",
		"{shift} \\ z \u016b c v b n m \u010d \u0161 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} \u0104 \u017d E R T Y U I O P \u012e \u201d \\",
		"A S D F G H J K L \u0172 \u0116 {enter}",
		"{shift} | Z \u016a C V B N M \u010c \u0160 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} { [ ] } {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Lithuanian Standard Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdlt2.html
 */
jQuery.keyboard.layouts['ms-Lithuanian Standard'] = {
	"name" : "ms-Lithuanian Standard",
	"lang" : ["lt"],
	"normal" : [
		"` ! - / ; : , . = ( ) ? x {bksp}",
		"{tab} \u0105 \u017e e r t y u i o p \u012f w q",
		"a s d \u0161 g h j k l \u0173 \u0117 {enter}",
		"{shift} < z \u016b c v b n m \u010d f / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ 1 2 3 4 5 6 7 8 9 0 + X {bksp}",
		"{tab} \u0104 \u017d E R T Y U I O P \u012e W Q",
		"A S D \u0160 G H J K L \u0172 \u0116 {enter}",
		"{shift} > Z \u016a C V B N M \u010c F / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u00b4 @ _ # $ \u00a7 ^ & * [ ] ' % {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} { } |",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \" {enter}",
		"{shift} \u2013 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u201e \u201c {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
