/* United Kingdom Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbduk.html
 */
jQuery.keyboard.layouts['ms-United Kingdom'] = {
	"name" : "ms-United Kingdom",
	"lang" : ["en-uk"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] #",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \u005c z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00ac ! \u0022 \u00a3 $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } ~",
		"A S D F G H J K L : @ {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u00a6 {empty} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00e9 {empty} {empty} {empty} \u00fa \u00ed \u00f3 {empty} {empty} {empty} {empty}",
		"\u00e1 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u00c9 {empty} {empty} {empty} \u00da \u00cd \u00d3 {empty} {empty} {empty} {empty}",
		"\u00c1 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* United Kingdom Extended Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdukx.html
 */
jQuery.keyboard.layouts['ms-United Kingdom Extended'] = {
	"name" : "ms-United Kingdom Extended",
	"lang" : ["en-uk"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] #",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \u005c z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00ac ! \u0022 \u00a3 $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } ~",
		"A S D F G H J K L : @ {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u00a6 {empty} \u00a8 {empty} \u20ac {empty} ^ {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} \u1e83 \u00e9 {empty} {empty} \u00fd \u00fa \u00ed \u00f3 {empty} {empty} {empty} ~",
		"\u00e1 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00b4 {enter}",
		"{shift} {empty} {empty} {empty} \u00e7 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} \u1e82 \u00c9 {empty} {empty} \u00dd \u00da \u00cd \u00d3 {empty} {empty} {empty} {empty}",
		"\u00c1 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ` {enter}",
		"{shift} {empty} {empty} {empty} \u00c7 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
