/* US-Dvorak Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbddv.html
 */
jQuery.keyboard.layouts['ms-US-Dvorak'] = {
	"name" : "ms-US-Dvorak",
	"lang" : ["en"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 [ ] {bksp}",
		"{tab} ' , . p y f g c r l / = \u005C",
		"a o e u i d h t n s - {enter}",
		"{shift} ; q j k x b m w v z {shift}",
		"{accept} {space} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) { } {bksp}",
		"{tab} \u0022 < > P Y F G C R L ? + |",
		"A O E U I D H T N S _ {enter}",
		"{shift} : Q J K X B M W V Z {shift}",
		"{accept} {space} {cancel}"
	]
};

/* US-Dvorak for left hand Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdusl.html
 */
jQuery.keyboard.layouts['ms-US-Dvorak for left hand'] = {
	"name" : "ms-US-Dvorak for left hand",
	"lang" : ["en"],
	"normal" : [
		"` [ ] / p f m l j 4 3 2 1 {bksp}",
		"{tab} ; q b y u r s o . 6 5 = \u005C",
		"- k c d t h e a z 8 7 {enter}",
		"{shift} ' x g v w n i , 0 9 {shift}",
		"{accept} {space} {cancel}"
	],
	"shift" : [
		"~ { } ? P F M L J $ # @ ! {bksp}",
		"{tab} : Q B Y U R S O > ^ % + |",
		"_ K C D T H E A Z * & {enter}",
		"{shift} \u0022 X G V W N I < ) ( {shift}",
		"{accept} {space} {cancel}"
	]
};

/* US-Dvorak for right hand Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdusr.html
 */
jQuery.keyboard.layouts['ms-US-Dvorak for right hand'] = {
	"name" : "ms-US-Dvorak for right hand",
	"lang" : ["en"],
	"normal" : [
		"` 1 2 3 4 j l m f p / [ ] {bksp}",
		"{tab} 5 6 q . o r s u y b ; = \u005C",
		"7 8 z a e h t d c k - {enter}",
		"{shift} 9 0 x , i n w v g ' {shift}",
		"{accept} {space} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ J L M F P ? { } {bksp}",
		"{tab} % ^ Q > O R S U Y B : + |",
		"& * Z A E H T D C K _ {enter}",
		"{shift} ( ) X < I N W V G \u0022 {shift}",
		"{accept} {space} {cancel}"
	]
};
