/* US English (Latin) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdus.html
 */
jQuery.keyboard.layouts['ms-US English (Latin)'] = {
	"name" : "ms-US English (Latin)",
	"lang" : ["en"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \u005c",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \u005c z x c v b n m , . / {shift}",
		"{accept} {space} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \u0022 {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {space} {cancel}"
	]
};

/* US English (IBM Arabic 238_L) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdusa.html
 */
jQuery.keyboard.layouts['ms-US English (IBM Arabic 238_L)'] = {
	"name" : "ms-US English (IBM Arabic 238_L)",
	"lang" : ["en"],
	"normal" : [
		"< 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] `",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \u005C z x c v b n m , . / {shift}",
		"{accept} {space} {cancel}"
	],
	"shift" : [
		"> ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } ~",
		"A S D F G H J K L : \u0022 {enter}",
		"{shift} | Z X C V B N M , . ? {shift}",
		"{accept} {space} {cancel}"
	]
};

/* US-International Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdusx.html
 */
jQuery.keyboard.layouts['ms-US-International'] = {
	"name" : "ms-US-International",
	"lang" : ["en"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ]",
		"a s d f g h j k l ; ' \u005C {enter}",
		"{shift} z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { }",
		"A S D F G H J K L : \u0022 | {enter}",
		"{shift} Z X C V B N M < > ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00A1 \u00B2 \u00B3 \u00A4 \u20AC \u00BC \u00BD \u00BE \u2018 \u2019 \u00A5 \u00D7 {bksp}",
		"{tab} \u00E4 \u00E5 \u00E9 \u00AE \u00FE \u00FC \u00FA \u00ED \u00F3 \u00F6 \u00AB \u00BB",
		"\u00E1 \u00DF \u00F0 {empty} {empty} {empty} {empty} {empty} \u00F8 \u00B6 \u00B4 \u00AC {enter}",
		"{shift} \u00E6 {empty} \u00A9 {empty} {empty} \u00F1 \u00B5 \u00E7 {empty} \u00BF {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} \u00B9 {empty} {empty} \u00A3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00F7 {bksp}",
		"{tab} \u00C4 \u00C5 \u00C9 {empty} \u00DE \u00DC \u00DA \u00CD \u00D3 \u00D6 {empty} {empty}",
		"\u00C1 \u00A7 \u00D0 {empty} {empty} {empty} {empty} {empty} \u00D8 \u00B0 \u00A8 \u00A6 {enter}",
		"{shift} \u00C6 {empty} \u00A2 {empty} {empty} \u00D1 {empty} \u00C7 {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
