/* German Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgr.html
 */
jQuery.keyboard.layouts['ms-German'] = {
	"name" : "ms-German",
	"lang" : ["de"],
	"normal" : [
		"^ 1 2 3 4 5 6 7 8 9 0 \u00DF \u00B4 {bksp}",
		"{tab} q w e r t z u i o p \u00FC +",
		"a s d f g h j k l \u00F6 \u00E4 # {enter}",
		"{shift} < y x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00B0 ! \" \u00A7 $ % & / ( ) = ? ` {bksp}",
		"{tab} Q W E R T Z U I O P \u00DC *",
		"A S D F G H J K L \u00D6 \u00C4 ' {enter}",
		"{shift} > Y X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u00B2 \u00B3 {empty} {empty} {empty} { [ ] } \\ {empty} {bksp}",
		"{tab} @ {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ~",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} | {empty} {empty} {empty} {empty} {empty} {empty} \u00B5 {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* German (IBM) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgr1.html
 */
jQuery.keyboard.layouts['ms-German (IBM)'] = {
	"name" : "ms-German (IBM)",
	"lang" : ["de"],
	"normal" : [
		"^ 1 2 3 4 5 6 7 8 9 0 \u00DF \u00B4 {bksp}",
		"{tab} q w e r t z u i o p \u00FC +",
		"a s d f g h j k l \u00F6 \u00E4 # {enter}",
		"{shift} < y x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00B0 ! \" \u00A7 $ % & / ( ) = ? ` {bksp}",
		"{tab} Q W E R T Z U I O P \u00DC *",
		"A S D F G H J K L \u00D6 \u00C4 ' {enter}",
		"{shift} > Y X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u00B2 \u00B3 {empty} {empty} {empty} { [ ] } \\ {empty} {bksp}",
		"{tab} @ {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ~",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} | {empty} {empty} {empty} {empty} {empty} {empty} \u00B5 {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
