/* Portuguese Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdpo.html
 */
jQuery.keyboard.layouts['ms-Portuguese'] = {
	"name" : "ms-Portuguese",
	"lang" : ["pt"],
	"normal" : [
		"\\ 1 2 3 4 5 6 7 8 9 0 ' \u00AB {bksp}",
		"{tab} q w e r t y u i o p + \u00B4",
		"a s d f g h j k l \u00E7 \u00BA ~ {enter}",
		"{shift} < z x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"| ! \" # $ % & / ( ) = ? \u00BB {bksp}",
		"{tab} Q W E R T Y U I O P * `",
		"A S D F G H J K L \u00C7 \u00AA ^ {enter}",
		"{shift} > Z X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} @ \u00A3 \u00A7 \u20AC {empty} { [ ] } {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00A8 ]",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Portuguese (Brazilian ABNT) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdbr.html
 */
jQuery.keyboard.layouts['ms-Portuguese (Brazilian ABNT)'] = {
	"name" : "ms-Portuguese (Brazilian ABNT)",
	"lang" : ["pt"],
	"normal" : [
		"' 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p \u00B4 [",
		"a s d f g h j k l \u00E7 ~ ] {enter}",
		"{shift} \\ z x c v b n m , . ; / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\" ! @ # $ % \u00A8 & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P ` {",
		"A S D F G H J K L \u00C7 ^ } {enter}",
		"{shift} | Z X C V B N M < > : ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00B9 \u00B2 \u00B3 \u00A3 \u00A2 \u00AC {empty} {empty} {empty} {empty} {empty} \u00A7 {bksp}",
		"{tab} / ? \u00B0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00AA",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00BA {enter}",
		"{shift} {empty} {empty} {empty} \u20A2 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00B0 {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
