/* Slovak Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdsl.html
 */
jQuery.keyboard.layouts['ms-Slovak'] = {
	"name" : "ms-Slovak",
	"lang" : ["sk"],
	"normal" : [
		"; + \u013e \u0161 \u010d \u0165 \u017e \u00fd \u00e1 \u00ed \u00e9 = \u00b4 {bksp}",
		"{tab} q w e r t z u i o p \u00fa \u00e4 \u0148",
		"a s d f g h j k l \u00f4 \u00a7 {enter}",
		"{shift} & y x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 1 2 3 4 5 6 7 8 9 0 % \u02c7 {bksp}",
		"{tab} Q W E R T Z U I O P / ( )",
		"A S D F G H J K L \" ! {enter}",
		"{shift} * Y X C V B N M ? : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u02d9 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} \\ | \u20ac {empty} {empty} {empty} {empty} {empty} {empty} ' \u00f7 \u00d7 \u00a4",
		"{empty} \u0111 \u0110 [ ] {empty} {empty} \u0142 \u0141 $ \u00df {enter}",
		"{shift} < > # & @ { } {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Slovak (QWERTY) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdsl1.html
 */
jQuery.keyboard.layouts['ms-Slovak (QWERTY)'] = {
	"name" : "ms-Slovak (QWERTY)",
	"lang" : ["sk"],
	"normal" : [
		"; + \u013e \u0161 \u010d \u0165 \u017e \u00fd \u00e1 \u00ed \u00e9 = \u00b4 {bksp}",
		"{tab} q w e r t y u i o p \u00fa \u00e4 \u0148",
		"a s d f g h j k l \u00f4 \u00a7 {enter}",
		"{shift} & z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 1 2 3 4 5 6 7 8 9 0 % \u02c7 {bksp}",
		"{tab} Q W E R T Y U I O P / ( )",
		"A S D F G H J K L \" ! {enter}",
		"{shift} * Z X C V B N M ? : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u02d9 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} \\ | \u20ac {empty} {empty} {empty} {empty} {empty} {empty} ' \u00f7 \u00d7 \u00a4",
		"{empty} \u0111 \u0110 [ ] {empty} {empty} \u0142 \u0141 $ \u00df {enter}",
		"{shift} < > # & @ { } {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
