/* Canadian French Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdca.html
 */
jQuery.keyboard.layouts['ms-Canadian French'] = {
	"name" : "ms-Canadian French",
	"lang" : ["fr-ca"],
	"normal" : [
		"# 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p ^ \u00b8 <",
		"a s d f g h j k l ; ` {enter}",
		"{shift} \u00ab z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"| ! \" / $ % ? & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P ^ \u00a8 >",
		"A S D F G H J K L : ` {enter}",
		"{shift} \u00bb Z X C V B N M ' . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\\ \u00b1 @ \u00a3 \u00a2 \u00a4 \u00ac \u00a6 \u00b2 \u00b3 \u00bc \u00bd \u00be {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00a7 \u00b6 [ ] }",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ~ { {enter}",
		"{shift} \u00b0 {empty} {empty} {empty} {empty} {empty} {empty} \u00b5 \u00af \u00ad {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Canadian French (Legacy) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdfc.html
 */
jQuery.keyboard.layouts['ms-Canadian French (Legacy)'] = {
	"name" : "ms-Canadian French (Legacy)",
	"lang" : ["fr-ca"],
	"normal" : [
		"\u00b0 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p ^ \u00e7 \u00e0",
		"a s d f g h j k l ; \u00e8 {enter}",
		"{shift} \u00f9 z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 ! \" # $ % ? & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P ^ \u00c7 \u00c0",
		"A S D F G H J K L : \u00c8 {enter}",
		"{shift} \u00d9 Z X C V B N M ' . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u00ac \u00b9 @ \u00b3 \u00bc \u00bd \u00be { [ ] } | \u00b8 {bksp}",
		"{tab} {empty} {empty} {empty} \u00b6 {empty} \u00a5 {empty} {empty} \u00f8 \u00fe \u00b0 ~ {empty}",
		"\u00e6 \u00df \u00f0 \u00aa {empty} {empty} {empty} {empty} {empty} \u00b4 {empty} {enter}",
		"{shift} \\ \u00ab \u00bb \u00a2 {empty} {empty} {empty} \u00b5 < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} \u00a1 \u00b2 \u00a3 \u00a4 {empty} {empty} {empty} {empty} \u00b1 {empty} \u00bf {empty} {bksp}",
		"{tab} {empty} {empty} {empty} \u00ae {empty} {empty} {empty} {empty} \u00d8 \u00de {empty} \u00a8 {empty}",
		"\u00c6 \u00a7 \u00d0 {empty} {empty} {empty} {empty} {empty} {empty} \u00b4 {empty} {enter}",
		"{shift} | {empty} {empty} \u00a9 {empty} {empty} {empty} \u00ba {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Canadian Multilingual Standard Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdcan.html
 */
jQuery.keyboard.layouts['ms-Canadian Multilingual Standard'] = {
	"name" : "ms-Canadian Multilingual Standard",
	"lang" : ["en-ca"],
	"normal" : [
		"/ 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p ^ \u00E7 {enter}",
		"a s d f g h j k l ; \u00E8 \u00E0 ",
		"{shift} \u00F9 z x c v b n m , . \u00E9 {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\\ ! @ # $ % ? & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P \u00A8 \u00C7 {enter}",
		"A S D F G H J K L : \u00C8 \u00C0 ",
		"{shift} \u00D9 Z X C V B N M ' \" \u00C9 {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"| {empty} {empty} {empty} {empty} {empty} {empty} { } [ ] {empty} \u00AC {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ` ~ {enter}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00B0 {empty} {empty} ",
		"{shift} {empty} \u00AB \u00BB {empty} {empty} {empty} {empty} {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
