/* Greek Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhe.html
 */
jQuery.keyboard.layouts['ms-Greek'] = {
	"name" : "ms-Greek",
	"lang" : ["el"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} ; \u03C2 \u03B5 \u03C1 \u03C4 \u03C5 \u03B8 \u03B9 \u03BF \u03C0 [ ]",
		"\u03B1 \u03C3 \u03B4 \u03C6 \u03B3 \u03B7 \u03BE \u03BA \u03BB \u0384 ' \\ {enter}",
		"{shift} < \u03B6 \u03C7 \u03C8 \u03C9 \u03B2 \u03BD \u03BC , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} : \u0385 \u0395 \u03A1 \u03A4 \u03A5 \u0398 \u0399 \u039F \u03A0 { }",
		"\u0391 \u03A3 \u0394 \u03A6 \u0393 \u0397 \u039E \u039A \u039B \u00A8 \" | {enter}",
		"{shift} > \u0396 \u03A7 \u03A8 \u03A9 \u0392 \u039D \u039C < > ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u00B2 \u00B3 \u00A3 \u00A7 \u00B6 {empty} \u00A4 \u00A6 \u00B0 \u00B1 \u00BD {bksp}",
		"{tab} {empty} {empty} \u20AC \u00AE {empty} \u00A5 {empty} {empty} {empty} {empty} \u00AB \u00BB",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0385 {empty} \u00AC {enter}",
		"{shift} {empty} {empty} {empty} \u00A9 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek (220) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhe220.html
 */
jQuery.keyboard.layouts['ms-Greek (220)'] = {
	"name" : "ms-Greek (220)",
	"lang" : ["el"],
	"normal" : [
		"\u00BD 1 2 3 4 5 6 7 8 9 0 ' ] {bksp}",
		"{tab} \u037E \u03C2 \u03B5 \u03C1 \u03C4 \u03C5 \u03B8 \u03B9 \u03BF \u03C0 + }",
		"\u03B1 \u03C3 \u03B4 \u03C6 \u03B3 \u03B7 \u03BE \u03BA \u03BB \u0384 \u00A8 # {enter}",
		"{shift} < \u03B6 \u03C7 \u03C8 \u03C9 \u03B2 \u03BD \u03BC , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00B1 ! \" \u00A3 $ % & / ( ) = ? [ {bksp}",
		"{tab} : ~ \u0395 \u03A1 \u03A4 \u03A5 \u0398 \u0399 \u039F \u03A0 * {",
		"\u0391 \u03A3 \u0394 \u03A6 \u0393 \u0397 \u039E \u039A \u039B \u00A8 \u0385 @ {enter}",
		"{shift} > \u0396 \u03A7 \u03A8 \u03A9 \u0392 \u039D \u039C ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u00B2 \u00B3 \u00A3 \u00A7 \u00B6 {empty} \u00A4 \u00A6 \u00B0 \u00B1 \u00BD {bksp}",
		"{tab} {empty} {empty} \u20AC \u00AE {empty} \u00A5 {empty} {empty} {empty} {empty} \u00AB \u00BB",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0385 \u0385 \u00AC {enter}",
		"{shift} {empty} {empty} {empty} \u00A9 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek (220) Latin Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhela2.html
 */
jQuery.keyboard.layouts['ms-Greek (220) Latin'] = {
	"name" : "ms-Greek (220) Latin",
	"lang" : ["el"],
	"normal" : [
		"\\ 1 2 3 4 5 6 7 8 9 0 ' ] {bksp}",
		"{tab} q w e r t y u i o p + }",
		"a s d f g h j k l \u0384 \u00A8 # {enter}",
		"{shift} < z x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"| ! \" # $ % & / ( ) = ? [ {bksp}",
		"{tab} Q W E R T Y U I O P * {",
		"A S D F G H J K L \u00A8 \u0385 @ {enter}",
		"{shift} > Z X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u00B2 \u00B3 \u00A3 \u00A7 \u00B6 {empty} \u00A4 \u00A6 \u00B0 \u00B1 \u00BD {bksp}",
		"{tab} {empty} {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00AB \u00BB",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0385 \u0385 \u00AC {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek (319) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhe319.html
 */
jQuery.keyboard.layouts['ms-Greek (319)'] = {
	"name" : "ms-Greek (319)",
	"lang" : ["el"],
	"normal" : [
		"\u00BD 1 2 3 4 5 6 7 8 9 0 ' + {bksp}",
		"{tab} \u00B7 \u03C2 \u03B5 \u03C1 \u03C4 \u03C5 \u03B8 \u03B9 \u03BF \u03C0 [ ]",
		"\u03B1 \u03C3 \u03B4 \u03C6 \u03B3 \u03B7 \u03BE \u03BA \u03BB \u0384 \u2019 \u00B2 {enter}",
		"{shift} \u00A7 \u03B6 \u03C7 \u03C8 \u03C9 \u03B2 \u03BD \u03BC , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00B1 ! \" \u00A3 $ % \u00AC / ( ) = \u00B0 * {bksp}",
		"{tab} \u2015 \u00A6 \u0395 \u03A1 \u03A4 \u03A5 \u0398 \u0399 \u039F \u03A0 \u00AB \u00BB",
		"\u0391 \u03A3 \u0394 \u03A6 \u0393 \u0397 \u039E \u039A \u039B \u00A8 \u2018 \u00B3 {enter}",
		"{shift} \u00A9 \u0396 \u03A7 \u03A8 \u03A9 \u0392 \u039D \u039C ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0385 {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek (319) Latin Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhela3.html
 */
jQuery.keyboard.layouts['ms-Greek (319) Latin'] = {
	"name" : "ms-Greek (319) Latin",
	"lang" : ["el"],
	"normal" : [
		"\\ 1 2 3 4 5 6 7 8 9 0 ' + {bksp}",
		"{tab} q w e r t y u i o p [ ]",
		"a s d f g h j k l \u00B4 ^ ` {enter}",
		"{shift} < z x c v b n m , . - {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"| ! \" # $ % & / ( ) = ? * {bksp}",
		"{tab} Q W E R T Y U I O P { }",
		"A S D F G H J K L \u00A8 ~ @ {enter}",
		"{shift} > Z X C V B N M ; : _ {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} \u20AC {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek Latin Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgkl.html
 */
jQuery.keyboard.layouts['ms-Greek Latin'] = {
	"name" : "ms-Greek Latin",
	"lang" : ["el"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ]",
		"a s d f g h j k l ; ' \\ {enter}",
		"{shift} z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { }",
		"A S D F G H J K L : \" | {enter}",
		"{shift} Z X C V B N M < > ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00A1 \u00B2 \u00B3 \u00A4 \u20AC \u00BC \u00BD \u00BE \u2018 \u2019 \u00A5 \u00D7 {bksp}",
		"{tab} \u00E4 \u00E5 \u00E9 \u00AE \u00FE \u00FC \u00FA \u00ED \u00F3 \u00F6 \u00AB \u00BB",
		"\u00E1 \u00DF \u00F0 {empty} {empty} {empty} {empty} {empty} \u00F8 \u00B6 \u00B4 \u00AC {enter}",
		"{shift} \u00E6 {empty} \u00A9 {empty} {empty} \u00F1 \u00B5 \u00E7 {empty} \u00BF {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} \u00B9 {empty} {empty} \u00A3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00F7 {bksp}",
		"{tab} \u00C4 \u00C5 \u00C9 {empty} \u00DE \u00DC \u00DA \u00CD \u00D3 \u00D6 {empty} {empty}",
		"\u00C1 \u00A7 \u00D0 {empty} {empty} {empty} {empty} {empty} \u00D8 \u00B0 \u00A8 \u00A6 {enter}",
		"{shift} \u00C6 {empty} \u00A2 {empty} {empty} \u00D1 {empty} \u00C7 {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Greek Polytonic Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdhept.html
 */
jQuery.keyboard.layouts['ms-Greek Polytonic'] = {
	"name" : "ms-Greek Polytonic",
	"lang" : ["el"],
	"normal" : [
		"~ 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} ; \u03C2 \u03B5 \u03C1 \u03C4 \u03C5 \u03B8 \u03B9 \u03BF \u03C0 [ ]",
		"\u03B1 \u03C3 \u03B4 \u03C6 \u03B3 \u03B7 \u03BE \u03BA \u03BB \u0384 ' \\ {enter}",
		"{shift} \u03B6 \u03C7 \u03C8 \u03C9 \u03B2 \u03BD \u03BC , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"` ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} : \u0385 \u0395 \u03A1 \u03A4 \u03A5 \u0398 \u0399 \u039F \u03A0 { }",
		"\u0391 \u03A3 \u0394 \u03A6 \u0393 \u0397 \u039E \u039A \u039B \u00A8 \" | {enter}",
		"{shift} \u0396 \u03A7 \u03A8 \u03A9 \u0392 \u039D \u039C < > ? {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"\u1FC1 \u03DA \u03DE \u03E0 \u00A3 \u00A7 \u00B6 {empty} \u00A4 \u00A6 \u00B0 \u00B1 \u00BD {bksp}",
		"{tab} \u1FFD {empty} \u20AC \u00AE {empty} \u00A5 {empty} {empty} {empty} {empty} \u00AB \u00BB",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0385 \u1FBF \u00AC {enter}",
		"{shift} {empty} {empty} \u00A9 {empty} {empty} {empty} {empty} {empty} {empty} \u1FBE {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} \u00B2 \u00B3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u1FDF {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u0387",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u1FFE \u1FDD {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u1FDE {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
