/* Georgian Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgeo.html
 */
jQuery.keyboard.layouts['ms-Georgian'] = {
	"name" : "ms-Georgian",
	"lang" : ["ka"],
	"normal" : [
		"\u201e ! ? \u2116 \u00a7 % : . ; , / \u2013 = {bksp}",
		"{tab} \u10e6 \u10ef \u10e3 \u10d9 \u10d4 \u10dc \u10d2 \u10e8 \u10ec \u10d6 \u10ee \u10ea (",
		"\u10e4 \u10eb \u10d5 \u10d7 \u10d0 \u10de \u10e0 \u10dd \u10da \u10d3 \u10df {enter}",
		"{shift} ( \u10ed \u10e9 \u10e7 \u10e1 \u10db \u10d8 \u10e2 \u10e5 \u10d1 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u201c 1 2 3 4 5 6 7 8 9 0 - + {bksp}",
		"{tab} \u10e6 \u10ef \u10e3 \u10d9 \u10d4 \u10dc \u10d2 \u10e8 \u10ec \u10d6 \u10ee \u10ea )",
		"\u10e4 \u10eb \u10d5 \u10d7 \u10d0 \u10de \u10e0 \u10dd \u10da \u10d3 \u10df {enter}",
		"{shift} ) \u10ed \u10e9 \u10e7 \u10e1 \u10db \u10d8 \u10e2 \u10e5 \u10d1 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} {empty} {empty} \u10f1 {empty} {empty} {empty} {empty} {empty} \u10f4 {empty} {empty}",
		"\u10f6 {empty} \u10f3 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} \u10f2 {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Georgian (Ergonomic) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgeoer.html
 */
jQuery.keyboard.layouts['ms-Georgian (Ergonomic)'] = {
	"name" : "ms-Georgian (Ergonomic)",
	"lang" : ["ka"],
	"normal" : [
		"\u201e ! \u2116 , ; % : ? . ( ) - \u201c {bksp}",
		"{tab} \u10e9 \u10de \u10e3 \u10eb \u10ed \u10e2 \u10d7 \u10dc \u10d5 \u10e8 \u10d9 \u10e5 /",
		"\u10ee \u10d8 \u10d0 \u10d4 \u10dd \u10d3 \u10db \u10e1 \u10e0 \u10d1 \u10d2 {enter}",
		"{shift} \\ \u10ef \u10f0 \u10e7 \u10e6 \u10df \u10d6 \u10ea \u10da \u10e4 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"' 1 2 3 4 5 6 7 8 9 0 + = {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00a7",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} / {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"` ! @ # $ \u20ac ^ & * ( ) \u2014 = {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u10fc \u10f3 {empty} [ ] \\",
		"\u10f4 \u10f2 \u10fa \u10f1 {empty} {empty} {empty} {empty} {empty} {empty} \u10f9 {enter}",
		"{shift} {empty} {empty} \u10f5 \u10f8 \u10f7 {empty} {empty} {empty} {empty} \u10f6 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ {empty} {empty} \u00a7 {empty} {empty} {empty} {empty} \u00b0 \u00ab \u00bb _ {empty} {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} I {empty} {empty} { } |",
		"{empty} {empty} D {empty} {empty} {empty} {empty} {empty} L {empty} \" {enter}",
		"{shift} {empty} {empty} X C V {empty} {empty} M < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Georgian (QWERTY) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdgeoqw.html
 */
jQuery.keyboard.layouts['ms-Georgian (QWERTY)'] = {
	"name" : "ms-Georgian (QWERTY)",
	"lang" : ["ka"],
	"normal" : [
		"\u201e 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} \u10e5 \u10ec \u10d4 \u10e0 \u10e2 \u10e7 \u10e3 \u10d8 \u10dd \u10de [ ] ~",
		"\u10d0 \u10e1 \u10d3 \u10e4 \u10d2 \u10f0 \u10ef \u10d9 \u10da ; ' {enter}",
		"{shift} \\ \u10d6 \u10ee \u10ea \u10d5 \u10d1 \u10dc \u10db , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u201c ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} {empty} \u10ed {empty} \u10e6 \u10d7 {empty} {empty} {empty} {empty} {empty} { } |",
		"{empty} \u10e8 {empty} {empty} {empty} {empty} \u10df {empty} {empty} : \" {enter}",
		"{shift} {empty} \u10eb {empty} \u10e9 {empty} {empty} N {empty} < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} \u201e \u201c {empty} \u20ac {empty} {empty} \u00b0 {empty} {empty} \u2014 \u2013 {bksp}",
		"{tab} {empty} {empty} \u10f1 \u00ae {empty} \u10f8 {empty} \u10f2 {empty} {empty} {empty} {empty} {empty}",
		"\u10fa {empty} {empty} \u10f6 \u10f9 \u10f5 \u10f7 {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} \u10f4 \u00a9 \u10f3 {empty} \u10fc {empty} \u00ab \u00bb {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
