/* Tibetan (PRC) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdtiprc.html
 */
jQuery.keyboard.layouts['ms-Tibetan (PRC)'] = {
	"name" : "ms-Tibetan (PRC)",
	"lang" : ["bo"],
	"normal" : [
		"\u0f68 \u0f21 \u0f22 \u0f23 \u0f24 \u0f25 \u0f26 \u0f27 \u0f28 \u0f29 \u0f20 \u0f67 \u0f5d {bksp}",
		"{tab} \u0f45 \u0f46 \u0f7a \u0f62 \u0f4f \u0f61 \u0f74 \u0f72 \u0f7c \u0f55 \u0f59 \u0f5a \u0f5b",
		"\u0f60 \u0f66 \u0f51 \u0f56 \u0f44 \u0f58 \u0f0b \u0f42 \u0f63 \u0f5e \u0f0d {enter}",
		"{shift} \u0f5f \u0f64 \u0f40 \u0f41 \u0f54 \u0f53 m \u0f50 \u0f47 / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u0f01 \u0f2a \u0f2b \u0f2c \u0f2d \u0f2e \u0f2f \u0f30 \u0f31 \u0f32 \u0f33 \u0f3c \u0f3d {bksp}",
		"{tab} \u0f15 \u0f16 \u0f17 \u0fbc \u0f4a \u0fbb \u0f18 \u0f19 \u0f1a \u0f1b \u0f1c \u0f1d \u0f1e",
		"\u0f71 \u0f1f \u0f4c \u0f3e \u0f3f \u0fcf \u0f02 \u0f03 \u0f06 \u0f07 \u0f38 {enter}",
		"{shift} \u0f34 \u0f65 \u0f69 \u0f87 \u0f86 \u0f4e M \u0f4b \u0f3a / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"\u0f00 \u0f76 \u0f77 \u0f78 \u0f79 \u0f73 \u0f09 \u0f0a \u0f0f \u0f10 \u0f12 \u0f0c \u0f13 {bksp}",
		"{tab} \u0f89 \u0f88 \u0fbe \u0f6a \u0f9a \u0fbf \u0f75 \u0f73 \u0fc0 \u0fc1 \u0fc2 \u0fc3 \u0f5c",
		"\u0fc4 \u0fc5 \u0f9c \u0f57 \u0fc6 \u0fc7 \u0fc8 \u0f43 \u0fc9 \u0fca \u0fcb {enter}",
		"{shift} \u0fcc \u0fb5 \u0fb9 \u0f36 \u0f82 \u0f9e \u0f52 \u0f9b \u0f8b {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
