/* Czech Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdcz.html
 */
jQuery.keyboard.layouts['ms-Czech'] = {
	"name" : "ms-Czech",
	"lang" : ["cs"],
	"normal" : [
		"; + \u011b \u0161 \u010d \u0159 \u017e \u00fd \u00e1 \u00ed \u00e9 = \u00b4 {bksp}",
		"{tab} q w e r t z u i o p \u00fa ) {empty}",
		"a s d f g h j k l \u016f \u00a7 {enter}",
		"{shift} \\ y x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 1 2 3 4 5 6 7 8 9 0 % \u02c7 {bksp}",
		"{tab} Q W E R T Z U I O P / ( '",
		"A S D F G H J K L \" ! {enter}",
		"{shift} | Y X C V B N M ? : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u02d9 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} \\ | \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00f7 \u00d7 \u00a4",
		"{empty} \u0111 \u0110 [ ] {empty} {empty} \u0142 \u0141 $ \u00df {enter}",
		"{shift} {empty} {empty} # & @ { } {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Czech (QWERTY) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdcz1.html
 */
jQuery.keyboard.layouts['ms-Czech (QWERTY)'] = {
	"name" : "ms-Czech (QWERTY)",
	"lang" : ["cs"],
	"normal" : [
		"; + \u011b \u0161 \u010d \u0159 \u017e \u00fd \u00e1 \u00ed \u00e9 = \u00b4 {bksp}",
		"{tab} q w e r t y u i o p \u00fa ) {empty}",
		"a s d f g h j k l \u016f \u00a7 {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 1 2 3 4 5 6 7 8 9 0 % \u02c7 {bksp}",
		"{tab} Q W E R T Y U I O P / ( '",
		"A S D F G H J K L \" ! {enter}",
		"{shift} | Z X C V B N M ? : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"` ! @ # $ % ^ & * ( ) - = {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} [ ] \\",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} ; \u00a4 {enter}",
		"{shift} \u00df {empty} {empty} {empty} {empty} {empty} {empty} {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} _ + {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} { } |",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} : ^ {enter}",
		"{shift} \u02dd {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00d7 \u00f7 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Czech Programmers Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdcz2.html
 */
jQuery.keyboard.layouts['ms-Czech Programmers'] = {
	"name" : "ms-Czech Programmers",
	"lang" : ["cs"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"; + \u011b \u0161 \u010d \u0159 \u017e \u00fd \u00e1 \u00ed \u00e9 = \u00b4 {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00fa ) {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u016f \u00a7 {enter}",
		"{shift} \u00df {empty} {empty} {empty} {empty} {empty} {empty} {empty} ? : {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"\u00b0 {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} % \u02c7 {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} / ( {empty}",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \" ! {enter}",
		"{shift} \u02dd {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00d7 \u00f7 {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
