/* Romanian (Legacy) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdro.html
 */
jQuery.keyboard.layouts['ms-Romanian (Legacy)'] = {
	"name" : "ms-Romanian (Legacy)",
	"lang" : ["ro"],
	"normal" : [
		"] 1 2 3 4 5 6 7 8 9 0 + ' {bksp}",
		"{tab} q w e r t z u i o p \u0103 \u00ee \u00e2",
		"a s d f g h j k l \u015f \u0163 {enter}",
		"{shift} < y x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"[ ! \" # \u00a4 % & / ( ) = ? * {bksp}",
		"{tab} Q W E R T Z U I O P \u0102 \u00ce \u00c2",
		"A S D F G H J K L \u015e \u0162 {enter}",
		"{shift} > Y X C V B N M ; : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u00b7 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} \\ | {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00f7 \u00d7 {empty}",
		"{empty} \u0111 \u0110 {empty} {empty} {empty} {empty} \u0142 \u0141 $ \u00df {enter}",
		"{shift} \u001c {empty} {empty} {empty} @ { } \u00a7 < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Romanian (Programmers) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdropr.html
 */
jQuery.keyboard.layouts['ms-Romanian (Programmers)'] = {
	"name" : "ms-Romanian (Programmers)",
	"lang" : ["ro"],
	"normal" : [
		"` 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p [ ] \\",
		"a s d f g h j k l ; ' {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"~ ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P { } |",
		"A S D F G H J K L : \" {enter}",
		"{shift} | Z X C V B N M < > / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u02d9 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} \u00e2 \u00df \u20ac {empty} \u021b {empty} {empty} \u00ee {empty} \u00a7 \u201e \u201d {empty}",
		"\u0103 \u0219 \u0111 {empty} {empty} {empty} {empty} {empty} \u0142 {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} \u00a9 {empty} {empty} {empty} {empty} \u00ab \u00bb {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u2013 \u00b1 {bksp}",
		"{tab} \u00c2 {empty} {empty} {empty} \u021a {empty} {empty} \u00ce {empty} {empty} {empty} {empty} {empty}",
		"\u0102 \u0218 \u0110 {empty} {empty} {empty} {empty} {empty} \u0141 {empty} {empty} {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};

/* Romanian (Standard) Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdrost.html
 */
jQuery.keyboard.layouts['ms-Romanian (Standard)'] = {
	"name" : "ms-Romanian (Standard)",
	"lang" : ["ro"],
	"normal" : [
		"\u201e 1 2 3 4 5 6 7 8 9 0 - = {bksp}",
		"{tab} q w e r t y u i o p \u0103 \u00ee \u00e2",
		"a s d f g h j k l \u0219 \u021b {enter}",
		"{shift} \\ z x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u201d ! @ # $ % ^ & * ( ) _ + {bksp}",
		"{tab} Q W E R T Y U I O P \u0102 \u00ce \u00c2",
		"A S D F G H J K L \u0218 \u021a {enter}",
		"{shift} | Z X C V B N M ; : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"` ~ \u02c7 ^ \u02d8 \u00b0 \u02db ` \u02d9 \u00b4 \u02dd \u00a8 \u00b8 {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} \u00a7 [ ] \\",
		"{empty} \u00df \u0111 {empty} {empty} {empty} {empty} {empty} \u0142 ; ' {enter}",
		"{shift} {empty} {empty} {empty} \u00a9 {empty} {empty} {empty} {empty} < > {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt-shift" : [
		"~ {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u2013 \u00b1 {bksp}",
		"{tab} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} { } |",
		"{empty} {empty} \u0110 {empty} {empty} {empty} {empty} {empty} \u0141 : \" {enter}",
		"{shift} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} \u00ab \u00bb {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
