/* Luxembourgish Keyboard Layout
 * generated from http://www.microsoft.com/resources/msdn/goglobal/keyboards/kbdsf.html
 */
jQuery.keyboard.layouts['ms-Luxembourgish'] = {
	"name" : "ms-Luxembourgish",
	"lang" : ["lb"],
	"normal" : [
		"\u00a7 1 2 3 4 5 6 7 8 9 0 ' ^ {bksp}",
		"{tab} q w e r t z u i o p \u00e8 \u00a8 $",
		"a s d f g h j k l \u00e9 \u00e0 {enter}",
		"{shift} < y x c v b n m , . / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"shift" : [
		"\u00b0 + \" * \u00e7 % & / ( ) = ? ` {bksp}",
		"{tab} Q W E R T Z U I O P \u00fc ! \u00a3",
		"A S D F G H J K L \u00f6 \u00e4 {enter}",
		"{shift} > Y X C V B N M ; : / {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	],
	"alt" : [
		"{empty} \u00a6 @ # \u00b0 \u00a7 \u00ac | \u00a2 {empty} {empty} \u00b4 ~ {bksp}",
		"{tab} {empty} {empty} \u20ac {empty} {empty} {empty} {empty} {empty} {empty} {empty} [ ] }",
		"{empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} { {enter}",
		"{shift} \\ {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {empty} {shift}",
		"{accept} {alt} {space} {alt} {cancel}"
	]
};
